# This script extracts amid I fragment from the whole spectrum
# Note that if the wavenumber interval is similar to the prototype, linear fit will not be performed

import numpy as np
import csv
import os
from stdspect import *


class Amid1Extract:
    def __init__(self, input_dir, output_dir):
        self._input_dir = input_dir
        self._output_dir = output_dir
        self._vernier = None
        self._input_data = None

    def check_output_dir(self):
        if os.path.exists(self._output_dir):
            i = 1
            output_file = self._output_dir[:-4]+'('+str(i)+').csv'
            while os.path.exists(output_file):
                i += 1
                output_file = self._output_dir[:-4]+'('+str(i)+').csv'
            self._output_dir = output_file

    def getdata(self):
        # Record the wavenumber values
        with open(self._input_dir) as f:
            reader = csv.reader(f)
            self._vernier = [float(entry) for entry in next(reader)[1:]]
            self._input_data = []
            for row in reader:
                self._input_data.append(row[1:])
        self._input_data = np.array(self._input_data, dtype=float)

    def extract(self, start, end, step):
        # Extract essential amid I region data points
        new = lp(self._input_data, self._vernier, new_vernier=RangeConstructor(start, end, step))

        # Write to a csv
        with open(self._output_dir, 'w', newline='') as f:
            writer = csv.writer(f)
            writer.writerow(['#'] + np.arange(start, end, step).tolist())
            for i,row in enumerate(new):
                writer.writerow([i+1] + row.tolist())

        print('Extraction complete.')

    def __call__(self, start, end, step):
        self.check_output_dir()
        self.getdata()
        self.extract(start, end, step)
