import numpy as np
import csv
import os

import multiprocessing as mp
import argparse
from amid1_peakfit_g import FindPeakCentroids, DetermineAmid1Centroids, fit
from stdspect import *

def uproc(token):
    Y = token[0]
    x = token[1]
    entry = token[2]
    maxerror = token[3]
    list1, list2, list3 = [], [], []
    list4, list5, list6 = [], [], []
    for row in Y:
        lr = fit(x, row, DetermineAmid1Centroids(FindPeakCentroids(x, row)), maxerror)
        list1.append(lr[0])
        list2.append(lr[1])
        list3.append(lr[2])
        list4.append(lr[3])
        list5.append(lr[4])
        list6.append(lr[5])
    if not os.path.exists('.tmp'):
        os.mkdir('.tmp')
    np.save('.tmp/.part'+str(entry)+'.npy', np.array([list1, list2, list3, list4, list5, list6]))

def uproc2(token):
    # struct token {np.ndarray spectra, np.ndarray vernier,
    # int entry, np.ndarray amide_list}
    Y = token[0]
    x = token[1]
    entry = token[2]
    alist = token[3]
    maxerror = token[4]
    start = token[5]
    list1, list2, list3 = [], [], []
    list4, list5, list6 = [], [], []
    for i,row in enumerate(Y):
        if alist[i+start]:
            lr = fit(x, row.astype(float), DetermineAmid1Centroids(FindPeakCentroids(x, row)), maxerror)
            list1.append(lr[0])
            list2.append(lr[1])
            list3.append(lr[2])
            list4.append(lr[3])
            list5.append(lr[4])
            list6.append(lr[5])
        else:
            list1.append(0)
            list2.append(0)
            list3.append(0)
            list4.append(0)
            list5.append(0)
            list6.append(0)
    if not os.path.exists('.tmp'):
        os.mkdir('.tmp')
    np.save('.tmp/.part'+str(entry)+'.npy', np.array([list1, list2, list3, list4, list5, list6]))

if __name__ == '__main__':
    parser = argparse.ArgumentParser()
    parser.add_argument('-p', type=int)
    parser.add_argument('-i', type=str)
    parser.add_argument('-o', type=str)
    parser.add_argument('-a', action='store_true')
    parser.add_argument('-e', action='store_true')
    parser.add_argument('--maxerror', type=float, default=0.07)
    args = parser.parse_args()

    input_data = []
    with open(args.i) as f:
        reader = csv.reader(f)
        for row in reader:
            input_data.append(row)
    input_data = np.array(input_data)

    axis_x, spectra = TruncateRange(input_data[1:, 1:].astype(float),
                                    input_data[0, 1:].astype(float),
                                    RangeConstructor(1720, 1600))
    totallen = len(spectra)

    if args.e:
        from tellamide import model, tellamide

        alist = tellamide(input_data[1:, 1:].astype(float), input_data[0, 1:].astype(float))
        divisions = [[spectra[totallen * i // args.p:totallen * (i + 1) // args.p, :],
                      axis_x, i, alist, args.maxerror,
                      totallen * i // args.p] for i in range(args.p)]
        with mp.Pool(args.p) as p:
            p.map(uproc2, divisions)

    else:
        divisions = [[spectra[totallen * i // args.p:totallen * (i + 1) // args.p, :],
                      axis_x, i, args.maxerror] for i in range(args.p)]
        with mp.Pool(args.p) as p:
            p.map(uproc, divisions)

    with open(args.o, 'w', newline='') as f:
        writer = csv.writer(f)
        n = 1
        if args.a:
            writer.writerow(['#', 'Absheet', 'Arcoil', 'Abturn', 'bsheet', 'rcoil', 'bturn'])
            for i in range(args.p):
                part = np.load('.tmp/.part'+str(i)+'.npy').transpose()
                for row in part:
                    writer.writerow([n] + row.tolist())
                    n += 1
        else:
            writer.writerow(['#', 'bsheet', 'rcoil', 'bturn'])
            for i in range(args.p):
                part = np.load('.tmp/.part'+str(i)+'.npy').transpose()
                for row in part:
                    writer.writerow([n, row[3], row[4], row[5]])
                    n += 1

    print('Done')