import numpy as np

class RangeConstructor:
    def __init__(self, *args):
        if len(args) == 1:
            self.start = 0
            self.end = args[0]
            self.step = 1
        elif len(args) == 2:
            self.start = args[0]
            self.end = args[1]
            self.step = 1
        elif len(args) == 3:
            self.start = args[0]
            self.end = args[1]
            self.step = args[2]

    def tolist(self):
        return np.arange(self.start, self.end, self.step).tolist()

def TruncateRange(array, vernier, new_range):
    # Truncate the whole spectra into ones with smaller range
    # Returns: (new_vernier, new_array)
    # new_range <- RangeConstructor object
    start_index, end_index = None, None
    cd = vernier[1] - vernier[0]
    if cd >= 0:
        raise ValueError('This function currently does not support positive steps.')
    for i in range(len(vernier)-1):
        current = vernier[i]
        if current == new_range.start or (current > new_range.start and vernier[i+1] < new_range.start):
            start_index = i
        elif current == new_range.end or (current > new_range.end and vernier[i+1] < new_range.end):
            end_index = i+1
    return vernier[start_index:end_index+1], array[:, start_index:end_index+1]

# Line parsing
def lp(array, vernier, new_vernier=RangeConstructor(1750, 1200, -1.5)):
    # vernier -> Iterable
    # new_vernier -> RangeConstructor object

    cd = vernier[1] - vernier[0]
    list_vernier = new_vernier.tolist()
    result = []
    done = True

    # Change the step to new_vernier.step
    if new_vernier.step < cd < 0:
        for i in range(len(vernier)):
            
            if done:
                try:
                    current = list_vernier.pop(0)
                    done = False
                except IndexError:
                    break
                    
            if vernier[i] >= current and vernier[i+1] <= current:
                done = True
                
                # Cross multiplication
                left_weight = vernier[i] - current
                right_weight = current - vernier[i+1]
                new = (array[:, i+1] * left_weight + array[:, i] * right_weight) / (left_weight + right_weight)
                result.append(new)
                
    elif cd <= new_vernier.step:
        i = 0
        for v in list_vernier:
            while vernier[i+1] > v:
                i += 1
            left_weight = vernier[i] - v
            right_weight = v - vernier[i+1]
            new = (array[:, i+1] * left_weight + array[:, i] * right_weight) / (left_weight + right_weight)
            result.append(new)
            
    return np.array(result).transpose()

if __name__ == '__main__':
    print('Lib for spectrum parsing.')
    input()